@@ -1,5 +1,5 @@
 <?php
-// $Id: module.textsanitizer.php,v 1.1 2004/09/09 05:14:50 onokazu Exp $
+// $Id: module.textsanitizer.php,v 1.25.2.2 2004/10/13 13:07:42 mithyt2 Exp $
 //  ------------------------------------------------------------------------ //
 //                XOOPS - PHP Content Management System                      //
 //                    Copyright (c) 2000 XOOPS.org                           //
@@ -106,14 +106,15 @@ class MyTextSanitizer
     function &smiley($message)
 	{
 		$db =& Database::getInstance();
-		if (empty($this->smileys)) {
+		if (count($this->smileys) == 0) {
 			if ($getsmiles = $db->query("SELECT * FROM ".$db->prefix("smiles"))){
 				while ($smiles = $db->fetchArray($getsmiles)) {
 					$message =& str_replace($smiles['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smiles['smile_url']).'" alt="" />', $message);
 					array_push($this->smileys, $smiles);
 				}
 			}
-		} else {
+		} 
+		elseif (is_array($this->smileys)) {
 			foreach ($this->smileys as $smile) {
 				$message =& str_replace($smile['code'], '<img src="'.XOOPS_UPLOAD_URL.'/'.htmlspecialchars($smile['smile_url']).'" alt="" />', $message);
 			}
